# Package Structure
- energicity
    - src
        - hello.py
        - powerleone.py
    - setup.py


## energicity
is the main package name and here is how you install the package:
```bash
pip install energicity
```

### hello
hello is a testing modul you use it by import it or import it's component, it's located in the `srs` directory
```python
import hello
```
or
```python
from hello import hello
```

### powerleone
powerleone contain all of the useful functionality for powerleone subsidery of EnergiCity in Sierra Leone, mostly this will be different than others because it will be in English and use PowerLeone technology like Africell SMS Gateway.
